/***********************************************************
 * $Id: fancyqt4browserframeagent_webkit.h 2090 2020-06-04 22:35:08Z cl_yubikey_2018a $
 *
 * FancyQT4 Widgets
 *
 * Copyright (C) 2009-2011 ev-i GmbH & IBCL e.U.
 * Copyright (C) 2011-2016 ITEG IT-Engineers GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ************************************************************/

#ifndef WIN32

#ifndef FANCYQT4WIDGETS_BROWSERFRAME_WEBKIT_H_
#define FANCYQT4WIDGETS_BROWSERFRAME_WEBKIT_H_

#include "fancyqt4browserframeagent.h"

#ifndef NDEBUG
#include <QtCore/qdebug.h>
#endif

//#include <QtGui/QKeyEvent>
//#include <QtGui/QTextCursor>

#include <QtWebKit/QWebView>

//#include <fancyqt4string.h>
//#include <fancyqt4widgetsi18n.h>
//#include <fancyqt4widgetslog.h>

//#include <fancyexception.h>


namespace Fancy {
namespace Qt4 {
namespace Widgets {


// https://stackoverflow.com/questions/9284511/reimplement-the-shouldinterruptjavascript-in-qt-c/20503280#20503280
class FANCYQT4WIDGETS_INTERNAL_API QWebPageWithoutJsWarning : public QWebPage {
    Q_OBJECT
public:
    QWebPageWithoutJsWarning(QObject* parent = 0, int _jsTimeoutPolicy = 0);
private:
    int jsTimeoutPolicy;
private slots:
    bool shouldInterruptJavaScript();
};


class FANCYQT4WIDGETS_INTERNAL_API BrowserFrameAgentWebkit : public BrowserFrameAgent {

	Q_OBJECT

public:

	BrowserFrameAgentWebkit();
	virtual ~BrowserFrameAgentWebkit();

	virtual QWidget* createWebWidget(
			QWidget *parentWidget=0,
			BrowserFrameAgent::BrowserType browserType=BrowserFrameAgent::AutoSelect);
	virtual QWidget* getWebWidget();

	virtual void setJavaScriptTimeoutPolicy(int jsTimeoutPolicy);

public slots:

	virtual void browseToUrl(const QString & url);
	virtual void browseToUrl(const QUrl & url);

	virtual void back();
	virtual void forward();
	virtual void print(QPrinter * printer) const;
	virtual void reload();
	virtual void stop();

    void onTitleChanged(const QString & title);
    //void onIconChanged ()
    //void onLinkClicked ( const QUrl & url )
    //void onLoadFinished ( bool ok )
    void onLoadProgress(int progressPercent); // win: 2 ints
    //void onLoadStarted ()
    //void onSelectionChanged ()
    //void onStatusBarMessage ( const QString & text )
    //void urlChanged ( const QUrl & url )

protected:

    QWebView *webview;

    int jsTimeoutPolicy;

};


} /* namespace Widgets */
} /* namespace Qt4 */
} /* namespace Fancy */

#endif // FANCYQT4WIDGETS_BROWSERFRAME_WEBKIT_H_

#endif // ndef WIN32
