/***********************************************************
 * $Id: fancyqt4charlistvalidator.h 1413 2014-12-24 16:23:56Z fancylibs $
 *
 * FancyQT4 Widgets
 *
 * Copyright (C) 2009-2011 ev-i GmbH & IBCL e.U.
 * Copyright (C) 2011-2013 ITEG IT-Engineers GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ************************************************************/

#ifndef FANCYQT4WIDGETS_CHARLISTVALIDATOR_H_
#define FANCYQT4WIDGETS_CHARLISTVALIDATOR_H_

#include <fancyqt4widgets.h>

#include <QtGui/QValidator>

#define FANCYQT4_CHARLIST_AZ_LOWER "abcdefghijklmnopqrstuvwxyz"
#define FANCYQT4_CHARLIST_AZ_UPPER "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
#define FANCYQT4_CHARLIST_AZ_BOTH  EQU_CHARLIST_AZ_LOWER+EQU_CHARLIST_AZ_UPPER
#define FANCYQT4_CHARLIST_DIGITS   "0123456789"


namespace Fancy {
namespace Qt4 {
namespace Widgets {
namespace impl { class CharListValidatorImpl; }

/**
 * Yet incomplete textedit with advance validation capabilities
 * including restrections to allowed set of characters and print space checking.
 */
class FANCYQT4WIDGETS_API CharListValidator : public QValidator {

public:

	CharListValidator(
			QObject * parent,
			const QString& allowed_characters="",
			const QString& char_regex_pattern="",
			const QString& codec_name="");
	virtual ~CharListValidator();

	virtual QValidator::State validate( QString &, int & ) const;

	// might damage the text, escpecially if a single character does not fulfill the regex!
	virtual void fixup( QString & ) const;

private:

	impl::CharListValidatorImpl *d;

};


} /* namespace Widgets */
} /* namespace Qt4 */
} /* namespace Fancy */

#endif /* FANCYQT4WIDGETS_CHARLISTVALIDATOR_H_ */
