/***********************************************************
 * $Id: fancyqt4combobox.h 1894 2017-12-01 16:15:11Z fancylibs $
 *
 * FancyQT4 Widgets
 *
 * Copyright (C) 2009-2011 ev-i GmbH & IBCL e.U.
 * Copyright (C) 2011-2013 ITEG IT-Engineers GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ************************************************************/

#ifndef FANCYQT4WIDGETS_COMBOBOX_H_
#define FANCYQT4WIDGETS_COMBOBOX_H_

#include <fancyqt4widgets.h>

#include <QtCore/QString>

#include <QtGui/QComboBox>


namespace Fancy {
namespace Qt4 {
namespace Widgets {
namespace impl {
class ComboBoxImpl;
//class ComboBoxValidator;
}

/**
 * A ComboBox with auto completion capabilities.
 */
class FANCYQT4WIDGETS_API ComboBox : public QComboBox {

	Q_OBJECT
	Q_PROPERTY( bool forwardEnter READ isForwardEnter WRITE setForwardEnter )
	Q_PROPERTY( bool validateStrict READ isValidateStrict WRITE setValidateStrict )

	impl::ComboBoxImpl *d;

public:
	ComboBox(QWidget *parent);
	virtual ~ComboBox();

	// if true, pressing Key_Enter/Key_Return are forwarded to the superclass resp. parent widget; default false
	void setForwardEnter(bool b);
	bool isForwardEnter() const;

	// if true and editable(), when loosing focus while value does not validate perfect, value is reset to the one from getting the focus; default true
	void setValidateStrict(bool b);
	bool isValidateStrict() const;

	// constructs a validator allowing all the current texts and sets it
	void resetValidator();

	bool isCurrentTextValid() const;

	int getCurrentItemIfValid() const;

	// sets the item current, that has data with itemData().toInt() == id
	// if the id could not be found and fallbackIndex >= 0, this index is set current
	void setCurrentId(int id, int fallbackIndex);

	// if there is a current valid item, it's itemData().toInt() is returned, otherwise valueIfInvalid
	int getCurrentIdIfValid(int valueIfInvalid) const;

	//virtual bool eventFilter( QObject *object, QEvent *event );
	virtual bool event( QEvent *event );

	void setLastAcceptableIndex(int i);

public slots:

    virtual void setCurrentIndex(int index);

    virtual void clearEditHistory();

signals:

	void returnPressed();


protected:

	virtual void keyPressEvent(QKeyEvent * ke);

	virtual void focusInEvent(QFocusEvent * e);
	virtual void focusOutEvent(QFocusEvent * e);
};


} /* namespace Widgets */
} /* namespace Qt4 */
} /* namespace Fancy */

#endif /* FANCYQT4WIDGETS_COMBOBOX_H_ */
