/***********************************************************
 * $Id: fancyqt4lineedit.h 1413 2014-12-24 16:23:56Z fancylibs $
 *
 * FancyQT4 Widgets
 *
 * Copyright (C) 2009-2011 ev-i GmbH & IBCL e.U.
 * Copyright (C) 2011-2013 ITEG IT-Engineers GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ************************************************************/

#ifndef FANCYQT4WIDGETS_LINEEDIT_H_
#define FANCYQT4WIDGETS_LINEEDIT_H_

#include <fancyqt4widgets.h>

#include <QtGui/QLineEdit>

namespace Fancy {
namespace Qt4 {
namespace Widgets {
namespace impl { class LineEditImpl; }

/**
 * Yet incomplete textedit with advance validation capabilities
 * including restrections to allowed set of characters and print space checking.
 */
class FANCYQT4WIDGETS_API LineEdit : public QLineEdit {

	Q_OBJECT

	Q_PROPERTY( int maxLength READ getMaxLength WRITE setMaxLength )
	Q_PROPERTY( bool autoUpcase READ isAutoUpcase WRITE setAutoUpcase )

public:

	LineEdit(QWidget *parent);
	virtual ~LineEdit();

	void setFont(const QFont &);

	int getMaxLength() const;
	void setMaxLength(int l);

	void setAllowedCharacters(const QString &allowed_characters);
	bool isPrintSpaceSatisfying(const QString &text) const;

	bool isAutoUpcase() const;
	void setAutoUpcase(bool b);

	QString getNonNullText() const;

signals:

	void changeRefused(const QString& message);

protected:

	virtual void keyPressEvent(QKeyEvent *e);
	virtual void keyReleaseEvent(QKeyEvent *e);

private:
	void imposeMaxLengthSizeHint();

	QKeyEvent *transformKeyEvent(QKeyEvent *e);
	QKeyEvent *upcaseKeyEvent(QKeyEvent *e);

private:

	impl::LineEditImpl *d;

};


} /* namespace Widgets */
} /* namespace Qt4 */
} /* namespace Fancy */

#endif /* FANCYQT4WIDGETS_LINEEDIT_H_ */
