/***********************************************************
 * $Id: fancyqt4logfilewatchdog.h 1326 2014-09-14 18:53:22Z fancylibs $
 *
 * FancyQT4 Widgets
 *
 * Copyright (C) 2009-2011 ev-i GmbH & IBCL e.U.
 * Copyright (C) 2011-2013 ITEG IT-Engineers GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ************************************************************/

#ifndef FANCYQT4WIDGETS_LOGFILEWATCHDOG_H_
#define FANCYQT4WIDGETS_LOGFILEWATCHDOG_H_

#include <fancyqt4linerecord.h>
#include <QtCore/QObject>

namespace Fancy {
namespace Qt4 {
namespace Widgets {
namespace impl { class LogFileWatchdogThread; }

/**
 * A watchdog to inform LogFileView about changes to log files
 */
class FANCYQT4WIDGETS_API LogFileWatchdog : public QObject {

	Q_OBJECT

	Q_PROPERTY(QString searchString READ getSearchString WRITE setSearchString)

	impl::LogFileWatchdogThread *d;

public:
    LogFileWatchdog(QObject *parent);
    virtual ~LogFileWatchdog();

    Q_SLOT void open(const QString &fn, QTextCodec *codec);

    Q_SLOT void requestLines(int firstLine, int nlines);
    Q_SLOT void requestStop();

    Q_SLOT void setSearchString(const QString &s);

    QString getSearchString() const;

    Q_SIGNAL void finished();
    Q_SIGNAL void ioError(const QString &message);
    Q_SIGNAL void linesRead(int firstLine, const Fancy::Qt4::Widgets::LineRecordList &lines);
    Q_SIGNAL void nlinesChanged(int nLines);
    Q_SIGNAL void contentChanged(int nLines, int lineHint);

    /**
     * Wait for the thread to stop after issuing @c requestStop().
     */
    void waitForStop();
};

} /* namespace Widgets */
} /* namespace Qt4 */
} /* namespace Fancy */
#endif /* FANCYQT4WIDGETS_LOGFILEWATCHDOG_H_ */
