/***********************************************************
 * $Id: fancyqt4statelabel.h 1326 2014-09-14 18:53:22Z fancylibs $
 *
 * FancyQT4 Widgets
 *
 * Copyright (C) 2009-2011 ev-i GmbH & IBCL e.U.
 * Copyright (C) 2011-2013 ITEG IT-Engineers GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ************************************************************/

#ifndef FANCYQT4WIDGETS_STATELABEL_H_
#define FANCYQT4WIDGETS_STATELABEL_H_

#define FANCYQT4WIDGETS_STATE_UNKNOWN -1

#include <fancyqt4widgets.h>

#include <QtGui/QLabel>

class QPixmap;
class QString;

namespace Fancy {
namespace Qt4 {
namespace Widgets {
namespace impl { class StateLabelImpl; }

/**
 * A Label to present component states with changing icons
 */
class FANCYQT4WIDGETS_API StateLabel : public QLabel {

	Q_OBJECT

	// declaring state a QProperty allows to use QPropertyAnimation
	// or to introduce a blinker based on QVariantAnimation
	Q_PROPERTY(int state READ lastPostedState WRITE postState)

	impl::StateLabelImpl *d;

public:
	StateLabel(QWidget *parent);
	virtual ~StateLabel();

	// registers a new state
	// use state FQW_STATE_UNKNOWN to specify a custom fallback icon
	// don't forget to post an initial state after registering all known states
	void registerState(
			int state,
			const QPixmap & pixmap,
			const QString & desc = 0); // FUTURE: Optional 2nd pixmap for blinking?

	// like above function, but with additional pixmap for blinking
	void registerState(
			int state,
			const QPixmap & pixmap,
			const QPixmap & otherPixmap,
			int blinkIntervalMillis = 1000,
			const QString & desc = 0); // FUTURE: Optional 2nd pixmap for blinking?

	int lastPostedState();
	QString lastPostedStateDesc();
	Q_SLOT void postState(int state);

	// for Demo modi
	Q_SLOT void rotateState();

protected:

};


} /* namespace Widgets */
} /* namespace Qt4 */
} /* namespace Fancy */

#endif /* FANCYQT4WIDGETS_STATELABEL_H_ */
