/***********************************************************
 * $Id: fancyqt4statusmessagebar.h 1722 2015-08-20 12:30:46Z fancylibs $
 *
 * FancyQT4 Widgets
 *
 * Copyright (C) 2009-2011 ev-i GmbH & IBCL e.U.
 * Copyright (C) 2011-2013 ITEG IT-Engineers GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ************************************************************/

#ifndef FANCYQT4WIDGETS_STATUSMESSAGEBAR_H_
#define FANCYQT4WIDGETS_STATUSMESSAGEBAR_H_


#include <fancyqt4widgets.h>

#include <QtCore/QDateTime>

#include <QtGui/QFont>
#include <QtGui/QFrame>
#include <QtGui/QWidget>

class QLabel;
class QString;

namespace Fancy {
namespace Qt4 {
namespace Widgets {
namespace impl { class StatusMessageBarImpl; }

/**
 * A message bar with clock and popup-history
 */
class FANCYQT4WIDGETS_API StatusMessageBar : public QFrame {

	Q_OBJECT

	Q_PROPERTY( QString dateTimeFormat READ dateTimeFormat WRITE setDateTimeFormat)
	Q_PROPERTY( int historySize READ historySize WRITE setHistorySize)
	Q_PROPERTY( int fadeOutTime READ fadeOutTime WRITE setFadeOutTime)
	Q_PROPERTY( bool logMessages READ isLogMessages WRITE setLogMessages )

	impl::StatusMessageBarImpl *d;

public:
	StatusMessageBar(QWidget *parent);
	virtual ~StatusMessageBar();

	void setDateTimeFormat(const QString & format);
	QString dateTimeFormat() const;

	void setHistorySize(int s);
	int historySize() const;

	void setFadeOutTime(int s);
	int fadeOutTime() const;

	void setLogMessages(bool b);
	bool isLogMessages() const;

	Q_SLOT void showMessage( const QString & message, bool bold=false);

	Q_SLOT void popup();
	Q_SLOT void popdown();

protected:

	void mousePressEvent(QMouseEvent *);
	void keyPressEvent(QKeyEvent *);
	void timerEvent(QTimerEvent *);
	void showEvent(QShowEvent *);
	void hideEvent(QHideEvent *);
	void resizeEvent( QResizeEvent * );
	bool eventFilter(QObject *, QEvent *);

	void adjustDateTimeSize();
};


} /* namespace Widgets */
} /* namespace Qt4 */
} /* namespace Fancy */

#endif /* FANCYQT4WIDGETS_STATUSMESSAGEBAR_H_ */
