/***********************************************************
 * $Id: fancyqt4textedit.h 1761 2016-03-22 15:09:56Z fancylibs $
 *
 * FancyQT4 Widgets
 *
 * Copyright (C) 2009-2011 ev-i GmbH & IBCL e.U.
 * Copyright (C) 2011-2013 ITEG IT-Engineers GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ************************************************************/

#ifndef FANCYQT4WIDGETS_TEXTEDIT_H_
#define FANCYQT4WIDGETS_TEXTEDIT_H_

#include <fancyqt4widgets.h>

#include <fancydrawingglobals.h>

#include <QtGui/QTextEdit>

// FULL IMPLEMENTATION AFTER Fancy::Drawing is completed

namespace Fancy {
namespace Qt4 {
namespace Widgets {
namespace impl { class TextEditImpl; }

/**
 * Yet incomplete textedit with advance validation capabilities
 * including restrections to allowed set of characters and print space checking.
 */
class FANCYQT4WIDGETS_API TextEdit : public QTextEdit {

	Q_OBJECT

	Q_PROPERTY( int maxLength READ getMaxLength WRITE setMaxLength )
	Q_PROPERTY( double printFontSize READ getPrintFontSize WRITE setPrintFontSize )
	Q_PROPERTY( double printWidth READ getPrintWidth WRITE setPrintWidth )
	Q_PROPERTY( double printLineSkip READ getPrintLineSkip WRITE setPrintLineSkip )
	Q_PROPERTY( int printLines READ getPrintLines WRITE setPrintLines )
	Q_PROPERTY( bool linefeedAllowed READ isLinefeedAllowed WRITE setLinefeedAllowed )

	//Q__ENUMS( Font )
	// we don't care about Qt properties too much, and don't want to mirror Drawing::Font for eternity
	//Q_PROPERTY( Drawing::Font printFont READ getPrintFont WRITE setPrintFont )

public:

	TextEdit(QWidget *parent);
	virtual ~TextEdit();

	int getMaxLength() const;
	void setMaxLength(int l);

	int getPrintLines() const;
	void setPrintLines(int l);

	double getPrintLineSkip() const;
	void setPrintLineSkip(double s);

	double getPrintWidth() const;
	void setPrintWidth(double w);

	double getPrintFontSize() const;
	void setPrintFontSize(double s);

	Drawing::Font getPrintFont() const;
	void setPrintFont(Drawing::Font f);

	bool isLinefeedAllowed() const;
	void setLinefeedAllowed(bool b);

	void setAllowedCharacters(const QString &allowed_characters);

	bool isPrintSpaceSatisfying(const QString &text) const;

	QString getNonNullText() const;

signals:

	void changeRefused(const QString& message);

protected slots:

	void textChangedSlot();

protected:

	void keyPressEvent (QKeyEvent * e);

	void logPositions(const std::string &where);


private:

	impl::TextEditImpl *d;

};


} /* namespace Widgets */
} /* namespace Qt4 */
} /* namespace Fancy */

#endif /* FANCYQT4WIDGETS_TEXTEDIT_H_ */
